
// This looks like a useful Camera API:
// Camera.pushCamera(eye, at);
// I think eye relates to eye level/position and at is the object to look at.
/**
 * This script runs in "game" scope and contains the actual camera logic for
 * enabling screenshot mode.
 */

import { InterfaceMode } from '/core/ui/interface-modes/interface-modes.js';


if (typeof ContextManager !== "undefined") {
    ContextManager.Register("OnGameInitComplete", function () {
        console.log("✅ Civ7 Screenshot Mode (Game scope): UI script initialized.");
    });
} else {
    console.log("❌ ContextManager is undefined! This script may not be running in the correct context.");
}

/**
 * Listen for engine-level input events. We'll respond when the player releases 
 * any keys bound to "screenshot-bare" or "screenshot-units".
 */
window.addEventListener("engine-input", (event) => {
    const actionName = event.detail?.name;
    const actionStatus = event.detail?.status;

    // FINISH typically corresponds to key-up, so we only handle the action once per press.
    if (actionStatus !== InputActionStatuses.FINISH) {
        return;
    }

    // Toggle screenshot mode
    if (actionName === "screenshot-units" || actionName === "screenshot-bare") {
        console.log("🔑 Toggling screenshot mode");
        InterfaceMode.switchTo("INTERFACEMODE_CINEMATIC");
        console.log("✅ Entering screenshot mode");
    }
    if (actionName === "screenshot-units") {
        WorldUI.setUnitVisibility(true);
    }
});
